@@ -9,6 +9,9 @@
     fac<-eval(appel$fac,sys.frame(0))
     X<-dudi1$tab
     X.lw<-dudi1$lw
+    if (!(identical(all.equal(X.lw,rep(1/nrow(X), nrow(X))),TRUE))) {
+    	stop ("Not implemented for non-uniform weights")
+    }
     X.lw<-X.lw/sum(X.lw)
     X.cw<-sqrt(dudi1$cw)
     X<-t(t(X)*X.cw)
@@ -16,5 +19,5 @@
 #   isim<-testinter(nrepet, X.lw, X.cw, length(unique(fac)), fac, X, nrow(X), ncol(X))/inertot
     isim<-testinter(nrepet, dudi1$lw, dudi1$cw, length(unique(fac)), fac, dudi1$tab, nrow(X), ncol(X))/inertot
     obs<-isim[1]
-    return(as.randtest(isim[-1],obs))
+    return(as.randtest(isim[-1],obs,call=match.call()))
 }
